@@ -62,7 +62,7 @@ lm.morantest <- function(model, listw, zero.policy=FALSE,
 	    "Variance")
     	method <- "Global Moran's I for regression residuals"
     	data.name <- paste("\n", paste(strwrap(paste("model: ",
-	    gsub(" *", " ", 
+	    gsub("[ ]+", " ", 
 	    paste(deparse(model$call), sep="", collapse="")))), collapse="\n"),
     	    "\nweights: ", deparse(substitute(listw)), "\n", sep="")
     	res <- list(statistic = statistic, p.value = p.value,
